==> open-xchange-documents-backend_7.8.2.orig.tar.bz2: open-xchange-documents-backend-7.8.2/com.openexchange.office.odf/src/com/openexchange/office/odt/dom/TextList.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.odt.dom;

import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import com.openexchange.office.odf.Namespaces;
import com.openexchange.office.odf.SaxContextHandler;

public class TextList {

	private final TextListItem parentTextListItem;
	private final int listLevel;

	// value or null
	private String id;
	private String styleName;
	private String continueList;
	private String continueNumbering;

	public TextList(TextListItem parentTextListItem) {
		this.parentTextListItem = parentTextListItem;
		listLevel = parentTextListItem!=null ? parentTextListItem.getParentTextList().getListLevel() + 1 : 0;
	}

	public TextList(TextListItem parentTextListItem, Attributes attributes) {
		this.parentTextListItem = parentTextListItem;
		listLevel = parentTextListItem!=null ? parentTextListItem.getParentTextList().getListLevel() + 1 : 0;
		applyAttributes(attributes);
	}

	private void applyAttributes(Attributes attributes) {
		id = attributes.getValue("xml:id");
		styleName = attributes.getValue("text:style-name");
		continueList = attributes.getValue("text:continue-list");
		continueNumbering = attributes.getValue("text:continue-numbering");
	}

	public void writeAttributes(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.addAttribute(output, Namespaces.XML, "id", "xml:id", id);
		SaxContextHandler.addAttribute(output, Namespaces.TEXT, "style-name", "text:style-name", styleName);
		SaxContextHandler.addAttribute(output, Namespaces.TEXT, "continue-list", "text:continue-list", continueList);
		SaxContextHandler.addAttribute(output, Namespaces.TEXT, "continue-numbering", "text:continue-numbering", continueNumbering);
	}

	public TextListItem getParentTextListItem() {
		return parentTextListItem;
	}

	public int getListLevel() {
		return listLevel;
	}

	public String getId() {
		return id;
	}

	public String getStyleName() {
		return styleName;
	}

	public void setStyleName(String styleName) {
		this.styleName = styleName;
	}

	public String getContinueList() {
		return continueList;
	}

	public String getContinueNumbering() {
		return continueNumbering;
	}
}

==> open-xchange-documents-backend_7.8.3.orig.tar.bz2: open-xchange-documents-backend-7.8.3/com.openexchange.office.odf/src/com/openexchange/office/odt/dom/TextList.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

/**
 * @author sven.jacobi@open-xchange.com
 */

package com.openexchange.office.odt.dom;

import org.apache.xml.serializer.SerializationHandler;
import org.xml.sax.Attributes;
import org.xml.sax.SAXException;

import com.openexchange.office.odf.Namespaces;
import com.openexchange.office.odf.SaxContextHandler;

public class TextList {

	private final TextListItem parentTextListItem;
	private final int listLevel;

	// value or null
	private String id;
	private String styleName;
	private String continueList;
	private Boolean continueNumbering;

	public TextList(TextListItem parentTextListItem) {
		this.parentTextListItem = parentTextListItem;
		listLevel = parentTextListItem!=null ? parentTextListItem.getParentTextList().getListLevel() + 1 : 0;
	}

	public TextList(TextListItem parentTextListItem, Attributes attributes) {
		this.parentTextListItem = parentTextListItem;
		listLevel = parentTextListItem!=null ? parentTextListItem.getParentTextList().getListLevel() + 1 : 0;
		applyAttributes(attributes);
	}

	private void applyAttributes(Attributes attributes) {
		id = attributes.getValue("xml:id");
		styleName = attributes.getValue("text:style-name");
		continueList = attributes.getValue("text:continue-list");
		final String contNumbering = attributes.getValue("text:continue-numbering");
		if(contNumbering!=null) {
		    continueNumbering = Boolean.parseBoolean(contNumbering);
		}
	}

	public void writeAttributes(SerializationHandler output)
		throws SAXException {

		SaxContextHandler.addAttribute(output, Namespaces.XML, "id", "xml:id", id);
		SaxContextHandler.addAttribute(output, Namespaces.TEXT, "style-name", "text:style-name", styleName);
		SaxContextHandler.addAttribute(output, Namespaces.TEXT, "continue-list", "text:continue-list", continueList);
		if(continueNumbering!=null) {
		    SaxContextHandler.addAttribute(output, Namespaces.TEXT, "continue-numbering", "text:continue-numbering", continueNumbering.toString());
		}
	}

	public TextListItem getParentTextListItem() {
		return parentTextListItem;
	}

	public int getListLevel() {
		return listLevel;
	}

	public String getId() {
		return id;
	}

	public String getStyleName(boolean deepSearch) {
	    if(!deepSearch) {
	        return styleName;
	    }
	    TextList textList = this;
	    while(true) {
	        final String styleName = textList.styleName;
	        if(styleName!=null&&!styleName.isEmpty()) {
	            return styleName;
	        }
	        if(textList.getParentTextListItem()==null) {
	            return null;
	        }
	        textList = textList.getParentTextListItem().getParentTextList();
	    }
	}

	public void setStyleName(String styleName) {
		this.styleName = styleName;
	}

	public String getContinueList() {
		return continueList;
	}

	public Boolean getContinueNumbering() {
		return continueNumbering;
	}

	public void setContinueNumbering(Boolean continueNumbering) {
	    this.continueNumbering = continueNumbering;
	}
}
